@@ -10,19 +10,26 @@
 #' @importFrom rlang .data
 #' @export
 
-mun_female_pop_totals <- function(source = "datasus"){
+mun_female_pop_totals <- function(source = "datasus") {
   # Assertions
-  checkmate::assert_choice(x = source, choices = c("datasus", "ufrn", "datasus2024"))
+  checkmate::assert_choice(
+    x = source,
+    choices = c("datasus", "ufrn", "datasus2024")
+  )
 
   # Estimates source
-  if(source == "datasus"){
+  if (source == "datasus") {
     mun_female_pop <- datasus_mun_female_pop()
-  } else if(source == "ufrn"){
+  } else if (source == "ufrn") {
     mun_female_pop <- ufrn_mun_female_pop()
-  } else if (source == "datasus2024"){
+  } else if (source == "datasus2024") {
     mun_female_pop <- datasus2024_mun_female_pop()
   }
 
+  if (is.null(mun_female_pop)) {
+    return(NULL)
+  }
+
   res <- mun_female_pop %>%
     dplyr::filter(.data$age_group == "Total") %>%
     dplyr::arrange(.data$code_muni, .data$year)
